@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-auth
-version: 1.4.13.1
-id: yesod-auth-1.4.13.1-02ce33af0017c100af6587c6e90a960e
-key: yesod_02SIi6douTk6Ivbqi2AdNr
+version: 1.4.13
+id: yesod-auth-1.4.13-afc8684a8e9e9b053e698b268da75a0d
+key: yesod_8AYO1DkBCVWBhjD9i50tRc
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,13 +20,13 @@ exposed-modules:
     Yesod.Auth.GoogleEmail Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded
 hidden-modules: Yesod.Auth.Routes Yesod.PasswordStore
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-auth-1.4.13.1
-hs-libraries: HSyesod-auth-1.4.13.1-02SIi6douTk6Ivbqi2AdNr
+import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13
+library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13
+data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-auth-1.4.13
+hs-libraries: HSyesod-auth-1.4.13-8AYO1DkBCVWBhjD9i50tRc
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
-    authenticate-1.3.3.1-de5806f9d15beccb070a770364a3018e
+    authenticate-1.3.3-8786f6078b464d3c3f52185ef882a223
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
@@ -36,24 +36,24 @@ depends:
     blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
-    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
+    cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     email-validate-2.2.0-2cb19fcad74f009f580f5d1a0c1a07e6
     file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
-    http-client-0.4.27.1-bb782af803807428bd58a3e7494afa2a
-    http-conduit-2.1.9-a114e1e30c63561e9380f63d9f83e5a8
+    http-client-0.4.27-1cd31210c8ec4a6e0b4cc467bd24f592
+    http-conduit-2.1.8-0cd87eafc953cbe4f675bdf50a2df8e2
     http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
+    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
     mime-mail-0.4.11-363f204ae632de52ba204fa0d2f16891
     network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
-    nonce-1.0.2-4d1212dfb084a803f723eea311d0a719
-    persistent-2.2.4.1-840a8f388c4f74e927e97d9dd2d8494d
-    persistent-template-2.1.6-6446adcdac00e4cf9aeae54844fe611d
+    nonce-1.0.2-c0bfd19efc8c42e1c2c83d3a058f813a
+    persistent-2.2.4.1-f7f5136d623755022a88522f150cf471
+    persistent-template-2.1.6-696af2309e8b2b7d269b843dd09030c3
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
+    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
@@ -62,9 +62,9 @@ depends:
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
-    yesod-core-1.4.20.1-8dce2c1559c72b98aae15f98b85f32e0
-    yesod-form-1.4.7-6556fa2dbba4c60b35adfc5077eb6d41
-    yesod-persistent-1.4.0.4-05d2e78a4f4be2f611edc21702f1c928
+    yesod-core-1.4.20-a64b314810952b5a1be9638e42c84862
+    yesod-form-1.4.7-65d4c1c67a98e3c400d577cc5e8a906b
+    yesod-persistent-1.4.0.4-a374b45e8b618c21d99c5a049b52b954
 haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
 haddock-html: /usr/share/doc/haskell-yesod-auth/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
